==> gstreamer-0.4.2.tar.gz: gstreamer-0.4.2/gst/gstenumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef __GST_ENUM_TYPES_H__
#define __GST_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "gstobject.h" */

GType gst_object_flags_get_type (void);
#define GST_TYPE_OBJECT_FLAGS (gst_object_flags_get_type())

/* enumerations from "gsttypes.h" */

GType gst_element_state_get_type (void);
#define GST_TYPE_ELEMENT_STATE (gst_element_state_get_type())

GType gst_element_state_return_get_type (void);
#define GST_TYPE_ELEMENT_STATE_RETURN (gst_element_state_return_get_type())

GType gst_result_get_type (void);
#define GST_TYPE_RESULT (gst_result_get_type())

/* enumerations from "gstautoplug.h" */

GType gst_autoplug_flags_get_type (void);
#define GST_TYPE_AUTOPLUG_FLAGS (gst_autoplug_flags_get_type())

/* enumerations from "gstbin.h" */

GType gst_bin_flags_get_type (void);
#define GST_TYPE_BIN_FLAGS (gst_bin_flags_get_type())

/* enumerations from "gstbuffer.h" */

GType gst_buffer_flag_get_type (void);
#define GST_TYPE_BUFFER_FLAG (gst_buffer_flag_get_type())

/* enumerations from "gstclock.h" */

GType gst_clock_return_get_type (void);
#define GST_TYPE_CLOCK_RETURN (gst_clock_return_get_type())

/* enumerations from "gstcpu.h" */

GType gst_cpu_flags_get_type (void);
#define GST_TYPE_CPU_FLAGS (gst_cpu_flags_get_type())

/* enumerations from "gstdata.h" */

GType gst_data_flags_get_type (void);
#define GST_TYPE_DATA_FLAGS (gst_data_flags_get_type())

/* enumerations from "gstelement.h" */

GType gst_element_flags_get_type (void);
#define GST_TYPE_ELEMENT_FLAGS (gst_element_flags_get_type())

/* enumerations from "gstevent.h" */

GType gst_event_type_get_type (void);
#define GST_TYPE_EVENT_TYPE (gst_event_type_get_type())

GType gst_event_flag_get_type (void);
#define GST_TYPE_EVENT_FLAG (gst_event_flag_get_type())

GType gst_seek_type_get_type (void);
#define GST_TYPE_SEEK_TYPE (gst_seek_type_get_type())

GType gst_seek_accuracy_get_type (void);
#define GST_TYPE_SEEK_ACCURACY (gst_seek_accuracy_get_type())

/* enumerations from "gstformat.h" */

GType gst_format_get_type (void);
#define GST_TYPE_FORMAT (gst_format_get_type())

/* enumerations from "gstpad.h" */

GType gst_pad_connect_return_get_type (void);
#define GST_TYPE_PAD_CONNECT_RETURN (gst_pad_connect_return_get_type())

GType gst_pad_query_type_get_type (void);
#define GST_TYPE_PAD_QUERY_TYPE (gst_pad_query_type_get_type())

GType gst_pad_direction_get_type (void);
#define GST_TYPE_PAD_DIRECTION (gst_pad_direction_get_type())

GType gst_pad_flags_get_type (void);
#define GST_TYPE_PAD_FLAGS (gst_pad_flags_get_type())

GType gst_pad_presence_get_type (void);
#define GST_TYPE_PAD_PRESENCE (gst_pad_presence_get_type())

/* enumerations from "gstplugin.h" */

GType gst_plugin_error_get_type (void);
#define GST_TYPE_PLUGIN_ERROR (gst_plugin_error_get_type())

/* enumerations from "gstprops.h" */

GType gst_props_type_get_type (void);
#define GST_TYPE_PROPS_TYPE (gst_props_type_get_type())

/* enumerations from "gstscheduler.h" */

GType gst_scheduler_flags_get_type (void);
#define GST_TYPE_SCHEDULER_FLAGS (gst_scheduler_flags_get_type())

GType gst_scheduler_state_get_type (void);
#define GST_TYPE_SCHEDULER_STATE (gst_scheduler_state_get_type())

/* enumerations from "gstthread.h" */

GType gst_thread_state_get_type (void);
#define GST_TYPE_THREAD_STATE (gst_thread_state_get_type())

/* enumerations from "gstregistry.h" */

GType gst_registry_return_get_type (void);
#define GST_TYPE_REGISTRY_RETURN (gst_registry_return_get_type())

GType gst_registry_flags_get_type (void);
#define GST_TYPE_REGISTRY_FLAGS (gst_registry_flags_get_type())

/* enumerations from "gsttimecache.h" */

GType gst_time_cache_certainty_get_type (void);
#define GST_TYPE_TIME_CACHE_CERTAINTY (gst_time_cache_certainty_get_type())

/* enumerations from "gstparse.h" */

GType gst_parse_error_get_type (void);
#define GST_TYPE_PARSE_ERROR (gst_parse_error_get_type())

G_END_DECLS

#endif /* __GST_ENUM_TYPES_H__ */

/* Generated data ends here */

==> gstreamer-0.5.0.tar.gz: gstreamer-0.5.0/gst/gstenumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef __GST_ENUM_TYPES_H__
#define __GST_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "gstobject.h" */

GType gst_object_flags_get_type (void);
#define GST_TYPE_OBJECT_FLAGS (gst_object_flags_get_type())

/* enumerations from "gsttypes.h" */

GType gst_element_state_get_type (void);
#define GST_TYPE_ELEMENT_STATE (gst_element_state_get_type())

GType gst_element_state_return_get_type (void);
#define GST_TYPE_ELEMENT_STATE_RETURN (gst_element_state_return_get_type())

GType gst_result_get_type (void);
#define GST_TYPE_RESULT (gst_result_get_type())

/* enumerations from "gstautoplug.h" */

GType gst_autoplug_flags_get_type (void);
#define GST_TYPE_AUTOPLUG_FLAGS (gst_autoplug_flags_get_type())

/* enumerations from "gstbin.h" */

GType gst_bin_flags_get_type (void);
#define GST_TYPE_BIN_FLAGS (gst_bin_flags_get_type())

/* enumerations from "gstbuffer.h" */

GType gst_buffer_flag_get_type (void);
#define GST_TYPE_BUFFER_FLAG (gst_buffer_flag_get_type())

/* enumerations from "gstcache.h" */

GType gst_cache_certainty_get_type (void);
#define GST_TYPE_CACHE_CERTAINTY (gst_cache_certainty_get_type())

GType gst_cache_entry_type_get_type (void);
#define GST_TYPE_CACHE_ENTRY_TYPE (gst_cache_entry_type_get_type())

GType gst_cache_lookup_method_get_type (void);
#define GST_TYPE_CACHE_LOOKUP_METHOD (gst_cache_lookup_method_get_type())

GType gst_assoc_flags_get_type (void);
#define GST_TYPE_ASSOC_FLAGS (gst_assoc_flags_get_type())

/* enumerations from "gstclock.h" */

GType gst_clock_entry_status_get_type (void);
#define GST_TYPE_CLOCK_ENTRY_STATUS (gst_clock_entry_status_get_type())

GType gst_clock_entry_type_get_type (void);
#define GST_TYPE_CLOCK_ENTRY_TYPE (gst_clock_entry_type_get_type())

GType gst_clock_return_get_type (void);
#define GST_TYPE_CLOCK_RETURN (gst_clock_return_get_type())

GType gst_clock_flags_get_type (void);
#define GST_TYPE_CLOCK_FLAGS (gst_clock_flags_get_type())

/* enumerations from "gstcpu.h" */

GType gst_cpu_flags_get_type (void);
#define GST_TYPE_CPU_FLAGS (gst_cpu_flags_get_type())

/* enumerations from "gstdata.h" */

GType gst_data_flags_get_type (void);
#define GST_TYPE_DATA_FLAGS (gst_data_flags_get_type())

/* enumerations from "gstelement.h" */

GType gst_element_flags_get_type (void);
#define GST_TYPE_ELEMENT_FLAGS (gst_element_flags_get_type())

/* enumerations from "gstevent.h" */

GType gst_event_type_get_type (void);
#define GST_TYPE_EVENT_TYPE (gst_event_type_get_type())

GType gst_event_flag_get_type (void);
#define GST_TYPE_EVENT_FLAG (gst_event_flag_get_type())

GType gst_seek_type_get_type (void);
#define GST_TYPE_SEEK_TYPE (gst_seek_type_get_type())

GType gst_seek_accuracy_get_type (void);
#define GST_TYPE_SEEK_ACCURACY (gst_seek_accuracy_get_type())

/* enumerations from "gstformat.h" */

GType gst_format_get_type (void);
#define GST_TYPE_FORMAT (gst_format_get_type())

/* enumerations from "gstpad.h" */

GType gst_pad_connect_return_get_type (void);
#define GST_TYPE_PAD_CONNECT_RETURN (gst_pad_connect_return_get_type())

GType gst_pad_query_type_get_type (void);
#define GST_TYPE_PAD_QUERY_TYPE (gst_pad_query_type_get_type())

GType gst_pad_direction_get_type (void);
#define GST_TYPE_PAD_DIRECTION (gst_pad_direction_get_type())

GType gst_pad_flags_get_type (void);
#define GST_TYPE_PAD_FLAGS (gst_pad_flags_get_type())

GType gst_pad_presence_get_type (void);
#define GST_TYPE_PAD_PRESENCE (gst_pad_presence_get_type())

/* enumerations from "gstplugin.h" */

GType gst_plugin_error_get_type (void);
#define GST_TYPE_PLUGIN_ERROR (gst_plugin_error_get_type())

/* enumerations from "gstprops.h" */

GType gst_props_type_get_type (void);
#define GST_TYPE_PROPS_TYPE (gst_props_type_get_type())

/* enumerations from "gstscheduler.h" */

GType gst_scheduler_flags_get_type (void);
#define GST_TYPE_SCHEDULER_FLAGS (gst_scheduler_flags_get_type())

GType gst_scheduler_state_get_type (void);
#define GST_TYPE_SCHEDULER_STATE (gst_scheduler_state_get_type())

/* enumerations from "gstthread.h" */

GType gst_thread_state_get_type (void);
#define GST_TYPE_THREAD_STATE (gst_thread_state_get_type())

/* enumerations from "gstregistry.h" */

GType gst_registry_return_get_type (void);
#define GST_TYPE_REGISTRY_RETURN (gst_registry_return_get_type())

GType gst_registry_flags_get_type (void);
#define GST_TYPE_REGISTRY_FLAGS (gst_registry_flags_get_type())

/* enumerations from "gstparse.h" */

GType gst_parse_error_get_type (void);
#define GST_TYPE_PARSE_ERROR (gst_parse_error_get_type())

G_END_DECLS

#endif /* __GST_ENUM_TYPES_H__ */

/* Generated data ends here */
